# Generated by Django 5.1.4 on 2025-05-11 22:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0018_alter_verb_indirect_objects'),
    ]

    operations = [
        migrations.AlterField(
            model_name='prepositionspecifier',
            name='specifier',
            field=models.CharField(choices=[('this', 'this'), ('any', 'any'), ('none', 'none')], db_index=True, default='none', max_length=255),
        ),
    ]
